@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-#  Copyright 2008-2013 Nokia Siemens Networks Oyj
+#  Copyright 2008-2016 Nokia Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,70 +14,69 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-"""Robot Framework Test Status Checker
+"""Robot Framework test status checker
+
+This tool processes Robot Framework output XML files and checks that test case
+statuses and messages are as expected. Main use case is post-processing output
+files got when testing Robot Framework test libraries using Robot Framework
+itself.
+
+The project is hosted at https://github.com/robotframework/statuschecker/.
+See documentation there for the syntax how to specify expected statuses and
+log messages.
 
 Command-line usage:
 
     python -m robotstatuschecker infile [outfile]
 
-Programmatical usage:
+Programmatic usage:
 
     from robotstatuschecker import process_output
     process_output('infile.xml', 'outfile.xml')
 
-This tool processes Robot Framework output XML files and checks that test case
-statuses and messages are as expected. Main use case is post-processing output
-files got when testing Robot Framework test libraries using Robot Framework
-itself. The tool assumes that Robot Framework is installed on the system.
-
-If output file is not given, the input file is considered to be also output
-file and it is edited in place.
-
-By default all test cases are expected to 'PASS' and have no message. Changing
-the expected status to 'FAIL' is done by having word 'FAIL' (in uppercase)
-somewhere in the test case documentation. Expected error message must then be
-given after 'FAIL'. Error message can also be specified as a regular
-expression by prefixing it with string 'REGEXP:'. Testing only the beginning
-of the message is possible with 'STARTS:' prefix.
-
-This tool also allows testing the created log messages. They are specified
-using format 'LOG x.y:z LEVEL Actual message', which is described in detail
-in the tool documentation.
+If an output file is not given, the input file is edited in place.
 """
 
-__version__ = '1.2'
+from __future__ import print_function
 
+from os.path import abspath
 import re
 import sys
-from os.path import abspath
 
 from robot.api import ExecutionResult, ResultVisitor
 from robot.utils import Matcher
 
 
-def process_output(inpath, outpath=None, verbose=True):
-    """Programmatic entry point to Status Checker.
+__version__ = "1.5.1"
 
-    When verbose is True, prints the paths to inpath and outpath.
+
+def process_output(inpath, outpath=None, verbose=True):
+    """The main programmatic entry point to status checker.
+
+    Args:
+        inpath (str): Path to Robot Framework XML output file to process.
+        outpath (str): Path where to write processed output. If not given,
+            ``inpath`` is edited in place.
+        verbose (bool): When ``True`` (default), prints both ``inpath`` and
+            ``outpath`` to console.
+
+    Returns:
+        int: Number of failed critical tests after post-processing.
     """
     if verbose:
-        print 'Checking %s' % abspath(inpath)
-    result = StatusChecker(inpath, outpath).process_output()
+        print('Checking %s' % abspath(inpath))
+    result = StatusChecker().process_output(inpath, outpath)
     if verbose and outpath:
-        print 'Output: %s' % abspath(outpath)
+        print('Output: %s' % abspath(outpath))
     return result.return_code
 
 
 class StatusChecker(ResultVisitor):
 
-    def __init__(self, inpath, outpath=None):
-        self._inpath = inpath
-        self._outpath = outpath
-
-    def process_output(self):
-        result = ExecutionResult(self._inpath)
+    def process_output(self, inpath, outpath=None):
+        result = ExecutionResult(inpath)
         result.suite.visit(self)
-        result.save(self._outpath)
+        result.save(outpath)
         return result
 
     def visit_test(self, test):
@@ -134,7 +133,7 @@ class ExpectedLog(object):
         return kw_index, msg_index
 
     def _split_level(self, message):
-        for level in ['TRACE', 'DEBUG', 'INFO', 'WARN', 'FAIL']:
+        for level in ['TRACE', 'DEBUG', 'INFO', 'WARN', 'FAIL', 'ERROR']:
             if message.startswith(level):
                 return level, message[len(level):].strip()
         return 'INFO', message
@@ -262,11 +261,11 @@ class LogMessageChecker(BaseChecker):
 
 if __name__ == '__main__':
     if '-h' in sys.argv or '--help' in sys.argv:
-        print __doc__
+        print(__doc__)
         sys.exit(251)
     try:
         rc = process_output(*sys.argv[1:])
     except TypeError:
-        print __doc__
+        print(__doc__)
         sys.exit(252)
     sys.exit(rc)
